==> hlint-2.1.14-12-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.1.14
id: hlint-2.1.14-Id39ov8CzGt9iOXBejHoVM
key: hlint-2.1.14-Id39ov8CzGt9iOXBejHoVM
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
abi: 6638760f4af2fa807460928ebd2c4c6a
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Timing CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
import-dirs: /usr/lib/ghc-8.6.4/site-local/hlint-2.1.14
library-dirs: /usr/lib/ghc-8.6.4/site-local/hlint-2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.1.14-Id39ov8CzGt9iOXBejHoVM
depends:
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP base-4.12.0.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 cpphs-1.20.8-ISt2D5MEyRI4QQUGFRtm5S
    data-default-0.7.1.1-3C0tdSCD1lzIk8WkrvBOoZ directory-1.3.3.0
    extra-1.6.14-5Tswu2tbShKGyB9aok2v7q filepath-1.4.2.1
    haskell-src-exts-1.21.0-BucpnMxfrtu30xH3ydsfMC
    haskell-src-exts-util-0.2.4-EjqwG7oo9Bubj6mbwge14
    hscolour-1.24.4-BEI90NJLSwF5tw227AM1ae process-1.6.5.0
    refact-0.3.0.2-1sV84vP3OHo15p4d2xAoYA text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-D1B9e4S36uhTArFMKIWAf
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    yaml-0.11.0.0-A3ZVfV7i42VBoOdDF6ARDI
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-2.1.14-13-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.1.14
id: hlint-2.1.14-LdduDlwH5xY4a1T0wQYLBT
key: hlint-2.1.14-LdduDlwH5xY4a1T0wQYLBT
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
abi: c361eef30ff5a1ac2e24ac6ed923d949
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Timing CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
import-dirs: /usr/lib/ghc-8.6.4/site-local/hlint-2.1.14
library-dirs: /usr/lib/ghc-8.6.4/site-local/hlint-2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.1.14-LdduDlwH5xY4a1T0wQYLBT
depends:
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP base-4.12.0.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 cpphs-1.20.8-ISt2D5MEyRI4QQUGFRtm5S
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    extra-1.6.14-5Tswu2tbShKGyB9aok2v7q filepath-1.4.2.1
    haskell-src-exts-1.21.0-BucpnMxfrtu30xH3ydsfMC
    haskell-src-exts-util-0.2.4-JuPAhNLtuNj85KJLo6JiAl
    hscolour-1.24.4-BEI90NJLSwF5tw227AM1ae process-1.6.5.0
    refact-0.3.0.2-1sV84vP3OHo15p4d2xAoYA text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-D1B9e4S36uhTArFMKIWAf
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    yaml-0.11.0.0-55g2vspuim9B5arWU8f1cj
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
